@@ -236,14 +236,14 @@ METHOD knh__Int_getSize(Ctx *ctx, knh_sfp_t *sfp)
 
 METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_int_t n = knh_rand();
+	knh_integer_t n = knh_rand();
 	if(IS_NOTNULL(sfp[1].o)) {
-		knh_int_t max = knh_abs(ARG_int(sfp[1]));
+		knh_integer_t max = ARG_integer(sfp[1]);
 		if(max > 0) {
 			KNH_RETURN_Int(ctx, sfp,  n % max);
 		}
 	}
-	KNH_RETURN_Int(ctx, sfp, n % KNH_UINT_MAX);
+	KNH_RETURN_Int(ctx, sfp, n);
 }
 
 /* ======================================================================== */
