@@ -69,8 +69,8 @@ METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_setAll(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Array_remove(Ctx *ctx, knh_sfp_t *sfp);
@@ -118,6 +118,17 @@ void knh_Boolean__s(Ctx *ctx, Boolean *o, OutputStream *w, String *m);
 knh_bytes_t knh_BytesNULL_tobytes(Bytes *o);
 char *knh_BytesNULL_tochar(Bytes *o);
 void knh_Bytes_unputc(Bytes *o);
+/* ../class/konoha/knh_BytesConv.c */
+void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
+void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, knh_ftraverse ftr);
+size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
+BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
+BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
+BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
+BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
+String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
+String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
+void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Bytes_api1.c */
 METHOD knh__Bytes_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Bytes_putc(Ctx *ctx, knh_sfp_t *sfp);
@@ -150,22 +161,33 @@ knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_int_t ch);
 knh_int_t knh_bytes_toint(knh_bytes_t t);
 knh_float_t knh_bytes_tofloat(knh_bytes_t t);
 knh_int64_t knh_bytes_toint64(knh_bytes_t t);
-/* ../class/konoha/knh_BytesConv.c */
-void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
-void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, knh_ftraverse ftr);
-size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
-BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
-BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
-BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
-BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
-String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
-String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
-void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Class.c */
 knh_Class_t *new_Class__type(Ctx *ctx, knh_type_t type);
 Object *knh_Class_fdefault(Ctx *ctx, knh_class_t cid);
 knh_hcode_t knh_Class_hashCode(Class *o);
 int knh_Class_compareTo(Class *o, Class *o2);
+/* ../class/konoha/knh_ClassMap.c */
+void knh_ClassMap_struct_init(Ctx *ctx, knh_ClassMap_struct *b, int init, Object *cs);
+void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, knh_ftraverse gc);
+ClassMap* new_ClassMap0(Ctx *ctx, knh_ushort_t capacity);
+void knh_ClassMap_resize(Ctx *ctx, ClassMap *o, size_t newsize);
+int knh_ClassMap_util_cmp(const Mapper *m1, const Mapper *m2);
+void knh_ClassMap_sort(Ctx *ctx, ClassMap *o);
+void knh_ClassMap_add(Ctx *ctx, ClassMap *o, Mapper *map);
+void knh_ClassMap__dump(Ctx *ctx, ClassMap *o, OutputStream *w, String *m);
+void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid);
+/* ../class/konoha/knh_ClassStruct.c */
+void knh_ClassStruct_struct_init(Ctx *ctx, knh_ClassStruct_struct *b, int init, Object *cs);
+void knh_ClassStruct_struct_traverse(Ctx *ctx, knh_ClassStruct_struct *b, knh_ftraverse gc);
+ClassStruct* new_ClassStruct0(Ctx *ctx, knh_struct_t sid, int method_size);
+void knh_ClassStruct_finit(Ctx *ctx, ClassStruct *o, knh_class_t self_cid, Object **v);
+knh_index_t knh_Class_indexOfField(knh_class_t cid, knh_fieldn_t fn);
+knh_index_t knh_Class_queryField(knh_class_t cid, knh_fieldn_t fnq);
+knh_cfield_t *knh_Class_fieldAt(knh_class_t cid, size_t n);
+void knh_Class_addMethod__fast(Ctx *ctx, knh_class_t cid, Method *mtd);
+void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
+Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
+void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
 /* ../class/konoha/knh_Class_api1.c */
 void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
 void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
@@ -180,27 +202,6 @@ knh_class_t knh_pmzclass(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_class_t
 knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t);
 char *TYPEQ(knh_type_t type);
 char *knh_TYPEN(Ctx *ctx, knh_type_t type);
-/* ../class/konoha/knh_ClassMap.c */
-void knh_ClassMap_struct_init(Ctx *ctx, knh_ClassMap_struct *b, int init, Object *cs);
-void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, knh_ftraverse gc);
-ClassMap* new_ClassMap0(Ctx *ctx, knh_ushort_t capacity);
-void knh_ClassMap_resize(Ctx *ctx, ClassMap *o, size_t newsize);
-int knh_ClassMap_util_cmp(const Mapper *m1, const Mapper *m2);
-void knh_ClassMap_sort(Ctx *ctx, ClassMap *o);
-void knh_ClassMap_add(Ctx *ctx, ClassMap *o, Mapper *map);
-void knh_ClassMap__dump(Ctx *ctx, ClassMap *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_ClassStruct.c */
-void knh_ClassStruct_struct_init(Ctx *ctx, knh_ClassStruct_struct *b, int init, Object *cs);
-void knh_ClassStruct_struct_traverse(Ctx *ctx, knh_ClassStruct_struct *b, knh_ftraverse gc);
-ClassStruct* new_ClassStruct0(Ctx *ctx, knh_struct_t sid, int method_size);
-void knh_ClassStruct_finit(Ctx *ctx, ClassStruct *o, knh_class_t self_cid, Object **v);
-knh_index_t knh_Class_indexOfField(knh_class_t cid, knh_fieldn_t fn);
-knh_index_t knh_Class_queryField(knh_class_t cid, knh_fieldn_t fnq);
-knh_cfield_t *knh_Class_fieldAt(knh_class_t cid, size_t n);
-void knh_Class_addMethod__fast(Ctx *ctx, knh_class_t cid, Method *mtd);
-void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
-Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
-void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
 /* ../class/konoha/knh_Connection.c */
 void knh_Connection_struct_init(Ctx *ctx, knh_Connection_struct *b, int init, Object *cs);
 void knh_Connection_struct_traverse(Ctx *ctx, knh_Connection_struct *b, knh_ftraverse ftr);
@@ -238,9 +239,8 @@ void knh_Context_closeBConvBuf(Ctx* ctx, Bytes *ba);
 void *knh_Context_mallocOnce(Ctx* ctx, size_t n);
 void knh_Context_freeOnce(Ctx* ctx, void *p);
 /* ../class/konoha/knh_DictIdx.c */
-void knh_DictIdx_struct_init(Ctx *ctx, knh_DictIdx_struct *b, int init, Object *cs);
-void knh_DictIdx_struct_traverse(Ctx *ctx, knh_DictIdx_struct *b, knh_ftraverse gc);
-DictIdx* new_DictIdx(Ctx *ctx, size_t initialCapacity, knh_int_t offset);
+DictIdx* new_DictIdx(Ctx *ctx, size_t init, knh_int_t offset);
+DictIdx* new_DictIdx__ignoreCase(Ctx *ctx, size_t init, knh_int_t offset);
 size_t knh_DictIdx_size(DictIdx *o);
 knh_index_t knh_DictIdx_index(Ctx *ctx, DictIdx *o, knh_bytes_t v);
 knh_index_t knh_DictIdx_add__fast(Ctx *ctx, DictIdx *o, String *term);
@@ -250,30 +250,13 @@ String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid);
 String* knh_DictIdx_get(DictIdx *o, knh_int_t termid);
 void knh_DictIdx_clear(Ctx *ctx, DictIdx *o);
 void knh_DictIdx__k(Ctx *ctx, DictIdx *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_DictMap_api1.c */
-METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
-METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
-Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
-Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
-METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictMapSet.c */
 knh_dict_t* knh_dict_resize(Ctx *ctx, knh_dict_t *a, size_t newsize);
 void knh_dict_traverse(Ctx *ctx, knh_dict_t *a, knh_ftraverse ftr);
 void knh_DictMap_sort(DictMap *o);
 void knh_DictSet_sort(DictSet *o);
+void knh_DictMap_toIgnoreCase(DictMap *o);
+void knh_DictSet_toIgnoreCase(DictSet *o);
 knh_dict_t *knh_dictmap_malloc(Ctx *ctx, size_t init);
 DictMap* new_DictMap0(Ctx *ctx, knh_int_t capacity);
 DictMap* new_DictMap(Ctx *ctx, knh_class_t p1, knh_int_t capacity);
@@ -303,6 +286,25 @@ void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uint_t n);
 void knh_DictSet_add(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_remove(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_clear(Ctx *ctx, DictSet *o);
+/* ../class/konoha/knh_DictMap_api1.c */
+METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
+METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
+Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
+Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
+Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
+METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
+void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictSet_api1.c */
 METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp);
@@ -328,13 +330,6 @@ void knh_Exception_struct_init(Ctx *ctx, knh_Exception_struct *b, int init, Obje
 void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, knh_ftraverse gc);
 Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag);
 Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue);
-/* ../class/konoha/knh_Exception_api1.c */
-METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp);
-int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg);
-METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m);
-void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
-void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ExceptionHandler.c */
 void knh_ExceptionHandler_struct_init(Ctx *ctx, knh_ExceptionHandler_struct *b, int init, Object *cs);
 void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, knh_ftraverse gc);
@@ -342,6 +337,13 @@ ExceptionHandler* new_ExceptionHandler(Ctx *ctx);
 Object *knh_ExceptionHandler_fdefault(Ctx *ctx, knh_class_t cid);
 void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *o, Exception *e);
 Exception* knh_ExceptionHandler_getCaughtException(ExceptionHandler *o);
+/* ../class/konoha/knh_Exception_api1.c */
+METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp);
+int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg);
+METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp);
+void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Float.c */
 Float* new_FloatX0(Ctx *ctx, knh_class_t cid, knh_float_t value);
 Float* new_FloatX(Ctx *ctx, knh_class_t cid, knh_float_t value);
@@ -352,6 +354,13 @@ int knh_Float_compareTo(Float *o, Float *o2);
 char *knh_format_Float(char *buf, size_t bufsiz, Float *o);
 knh_float_t knh_float_max(knh_float_t a, knh_float_t b);
 knh_float_t knh_float_min(knh_float_t a, knh_float_t b);
+/* ../class/konoha/knh_FloatUnit.c */
+void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
+void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, knh_ftraverse gc);
+FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
+void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
+void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
+void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
 /* ../class/konoha/knh_Float_api1.c */
 METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp);
@@ -378,13 +387,6 @@ void knh_Float__f(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__k(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__bits(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__dump(Ctx *ctx, Float *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_FloatUnit.c */
-void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
-void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, knh_ftraverse gc);
-FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
-void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
-void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
-void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
 /* ../class/konoha/knh_HashMap.c */
 void knh_HashMap_struct_init(Ctx *ctx, knh_HashMap_struct *b, int init, Object *cs);
 knh_hashmapentry_t *new_hashmapentry(Ctx *ctx, HashMap *o);
@@ -447,6 +449,14 @@ knh_int_t knh_int_min(knh_int_t a, knh_int_t b);
 knh_uint_t knh_uint_max(knh_uint_t a, knh_uint_t b);
 knh_uint_t knh_uint_min(knh_uint_t a, knh_uint_t b);
 knh_integer_t knh_IntNULL_toint(Int *v);
+/* ../class/konoha/knh_IntUnit.c */
+void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
+void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, knh_ftraverse gc);
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
+void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
 /* ../class/konoha/knh_Int_api1.c */
 METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp);
@@ -479,14 +489,6 @@ void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__x(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits);
 void knh_Int__bits(Ctx *ctx, Int *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_IntUnit.c */
-void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
-void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, knh_ftraverse gc);
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
-void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
@@ -564,9 +566,9 @@ knh_class_t knh_tclass_loadURN(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 knh_type_t knh_NameSpace_tagcid(Ctx *ctx, NameSpace *o, knh_class_t bcid, knh_bytes_t tag);
 void knh_NameSpace_setFuncClass(Ctx *ctx, NameSpace *o, knh_methodn_t mn, knh_class_t c);
 knh_class_t knh_NameSpace_getFuncClass(Ctx *ctx, NameSpace *o, knh_bytes_t funcname);
-knh_bool_t knh_NameSpace_existsLocalConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
-void knh_NameSpace_addLocalConst(Ctx *ctx, NameSpace *o, String *name, Object *value);
-Object* knh_NameSpace_getLocalConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
+knh_bool_t knh_NameSpace_existsConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
+void knh_NameSpace_addConst(Ctx *ctx, NameSpace *o, String *name, Object *value);
+Object* knh_NameSpace_getConst(Ctx *ctx, NameSpace *o, knh_bytes_t name);
 void knh_NameSpace_loaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid);
 knh_bool_t knh_NameSpace_isLoaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid);
 /* ../class/konoha/knh_Nue.c */
@@ -716,6 +718,15 @@ int knh_String_compareTo(String *o, String *o2);
 char *knh_StringNULL_tochar(String *o);
 knh_bytes_t knh_String_tobytes(String *o);
 knh_bytes_t knh_StringNULL_tobytes(String *o);
+/* ../class/konoha/knh_StringParser.c */
+Object* new_String_parseOf(Ctx *ctx, String *p);
+knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
+Object *new_Object_parseOf(Ctx *ctx, String *s);
+/* ../class/konoha/knh_StringUnit.c */
+void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
+void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, knh_ftraverse gc);
+StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
+Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_String_api1.c */
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
 knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
@@ -746,15 +757,6 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m);
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
 knh_bytes_t knh_bytes_mofflen(knh_bytes_t m, size_t moff, size_t mlen);
-/* ../class/konoha/knh_StringParser.c */
-Object* new_String_parseOf(Ctx *ctx, String *p);
-knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
-Object *new_Object_parseOf(Ctx *ctx, String *s);
-/* ../class/konoha/knh_StringUnit.c */
-void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
-void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, knh_ftraverse gc);
-StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
-Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_System.c */
 Object *knh_System_fdefault(Ctx *ctx, knh_class_t cid);
 char * knh_bytes_nzenvkey(knh_bytes_t t, char *buf, size_t bufsiz);
@@ -880,8 +882,6 @@ Stmt *knh_Stmt_tail(Stmt *o);
 Stmt* knh_StmtNULL_tail_append(Ctx *ctx, Stmt *o, Stmt *stmt);
 void knh_Stmt__s(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
 void knh_Stmt__dump(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
-/* ../class/konohac/knh_Stmt_const.c */
-Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_StmtCLASS.c */
 void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid);
 void knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
@@ -986,6 +986,8 @@ void knh_StmtUUNIT_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 void knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUMAPMAP_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUALIAS(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
+/* ../class/konohac/knh_Stmt_const.c */
+Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_Term.c */
 knh_type_t knh_Term_type(Term *tm);
 Token *knh_Term_firstToken(Term *tm);
@@ -1014,6 +1016,14 @@ knh_bytes_t knh_Token_tobytes(Token *o);
 void knh_Token__s(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__k(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__dump(Ctx *ctx, Token *o, OutputStream *w, String *m);
+/* ../class/konohac/knh_tokens_t.c */
+Token* knh_tokens_curToken(knh_tokens_t *tc);
+int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
+void knh_tokens_nextStmt(knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
+String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
+void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../class/konohac/knh_Token_const.c */
 Token* new_TokenCONST(Ctx *ctx, Any *fln, Any *data);
 void knh_Token_setCONST(Ctx *ctx, Token *o, Any *data);
@@ -1025,14 +1035,6 @@ void knh_Token_setLCONST(Ctx *ctx, Token *tk, NameSpace *ns);
 knh_bool_t knh_Token_isSystemVariable(Token *tk);
 void knh_Token_constSystemVariable(Ctx *ctx, Token *tk, Compiler *cpr);
 Token *knh_Token_const(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns);
-/* ../class/konohac/knh_tokens_t.c */
-Token* knh_tokens_curToken(knh_tokens_t *tc);
-int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
-void knh_tokens_nextStmt(knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
-String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
-void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../konoha/deps/cygwin/filesystem__cygwin.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
@@ -1103,6 +1105,7 @@ knh_bool_t knh_tConst_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name,
 void KNH_TCONST(Ctx *ctx, String *name, Object *value);
 void KNH_TCONST__T(Ctx *ctx, char *name, Object *value);
 knh_bool_t knh_tConst_addGlobalConst(Ctx *ctx, String *name, Object *value);
+void knh_tConst__man(Ctx *ctx, knh_class_t cid, OutputStream *w);
 Object *knh_tConst_systemValue(Ctx *ctx, int n);
 /* ../konoha/runtime/knh_tContext.c */
 void knh_tContext_init0(void);
@@ -1186,8 +1189,10 @@ Array *knh_sfp_toArray(Ctx *ctx, knh_sfp_t *varg);
 void knh_dynamiccall(Ctx *ctx, knh_sfp_t *mbp);
 void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_ext.c */
-void knh_srand(knh_uint_t seed);
-knh_uint_t knh_rand();
+void knh_srand(knh_uinteger_t seed);
+METHOD knh__System_setRandomSeed(Ctx *ctx, knh_sfp_t *sfp);
+knh_uinteger_t knh_rand();
+knh_float_t knh_float_rand();
 /* ../konoha/runtime/konoha_file.c */
 char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
 char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
@@ -1203,7 +1208,7 @@ int knh_verbose(void);
 /* ../konoha/runtime/konoha_shell.c */
 METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_readline(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_readLine(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_sync.c */
 void knh_Object_lock(Ctx *ctx, Object *o);
