@@ -38,7 +38,7 @@
 #define KONOHA_VERSION   PACKAGE_VERSION
 #else
 #define KONOHA_NAME     "konoha"
-#define KONOHA_VERSION  "0.2.1"
+#define KONOHA_VERSION  "0.2.2"
 #endif
 
 #define KONOHA_URL		"http://konoha.sourceforge.jp/"
@@ -138,6 +138,15 @@
 	#define KNH_USING_MATH    32
 #endif
 
+/* ======================================================================== */
+
+//#define KNH_FASTMODE 1
+
+#ifdef KNH_FASTMODE
+#define KNH_USING_FASTMALLOC 1
+#define KNH_USING_WORDKLRC   1
+#endif
+
 /* ======================================================================== */
 /* COMMON */
 
