@@ -67,16 +67,6 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 
 /* ======================================================================== */
 
-#define ARG_int(a)         ((a.i)->value)
-#define ARG_uint(a)        ((knh_uinteger_t)(a.i)->value)
-#define ARG_float(a)       ((float)(a.f)->value)
-#define ARG_double(a)      ((double)(a.f)->value)
-#define ARG_char(a)        (knh_String_tochar(a.s))
-#define ARG_bytes(a)       (knh_Bytes_tobytes(a.s))
-#define ARG_cid(a)         ((a.c)->cid)
-#define ARG_Object_cid(a)  knh_Object_cid(a.o)
-
-
 #define KNH_RETURN(ctx, sfp, v)      {\
 		KNH_NGCSETv(ctx, sfp[-1].o, v); \
 		return; \
@@ -460,7 +450,7 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 			knh_ExceptionHandler_setJumpable(_hdr, 1); \
 			int jump = KNH_SETJUMP(_hdr); \
 			if(jump != 0) { \
-				pc = DP(_hdr)->pc; \
+				pc = (knhvmc_t*)DP(_hdr)->pc; \
 				KNH_SETv(ctx, esfp, DP(_hdr)->caught); \
 				DBG2_P("JUMPED jump=%d .. %p", jump, esfp); \
 				VM_JMP(ctx, PC, JUMP); \
@@ -481,7 +471,7 @@ int knh_Method_pctoline(Method *mtd, knhvmc_t *pc);
 			int jump = KNH_SETJUMP(_hdr); \
 			if(jump != 0) { \
 				DBG2_P("JUMPED jump=%d ..", jump); \
-				pc = DP(_hdr)->pc; \
+				pc = (knhvmc_t*)DP(_hdr)->pc; \
 				VM_JMP(ctx, PC, JUMP); \
 			} \
 			DP(_hdr)->pc = pc; \
